""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.ufile.schemas import apis


class UFileClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UFileClient, self).__init__(config, transport, middleware, logger)

    def create_bucket(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateBucket - 创建Bucket

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **BucketName** (str) - (Required) 待创建Bucket的名称，具有全局唯一性
        - **Type** (str) - Bucket访问类型，public或private; 默认为private

        **Response**

        - **BucketId** (str) - 已创建Bucket的ID
        - **BucketName** (str) - 已创建Bucket的名称

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateBucketRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateBucket", d, **kwargs)
        return apis.CreateBucketResponseSchema().loads(resp)

    def create_ufile_life_cycle(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUFileLifeCycle - 创建生命周期管理

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BucketName** (str) - (Required) 存储空间名称
        - **LifeCycleName** (str) - (Required) 生命周期名称
        - **Prefix** (str) - (Required) 生命周期所适用的前缀；*为整个存储空间文件；一条规则只支持一个文件前缀；
        - **Status** (str) - (Required) Enabled -- 启用，Disabled -- 不启用
        - **ArchivalDays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后，自动变为归档存储类型；参数范围：[7,36500]，0代表不启用
        - **Days** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动删除；参数范围：[7,36500]，0代表不启用
        - **IADays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后，自动变为低频存储类型；参数范围：[7,36500]，0代表不启用

        **Response**

        - **LifeCycleId** (str) - 生命周期Id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUFileLifeCycleRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUFileLifeCycle", d, **kwargs)
        return apis.CreateUFileLifeCycleResponseSchema().loads(resp)

    def create_ufile_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUFileToken - 创建US3令牌

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **TokenName** (str) - (Required) 令牌名称
        - **AllowedBuckets** (list) - 令牌允许操作的bucket，默认*表示全部
        - **AllowedOps** (list) - 令牌允许执行的操作，[ TOKEN_ALLOW_NONE , TOKEN_ALLOW_READ , TOKEN_ALLOW_WRITE , TOKEN_ALLOW_DELETE , TOKEN_ALLOW_LIST, TOKEN_ALLOW_IOP , TOKEN_ALLOW_DP  ，TOKEN_DENY_UPDATE]。默认TOKEN_ALLOW_NONE
        - **AllowedPrefixes** (list) - 令牌允许操作的key前缀，默认*表示全部
        - **BlackIPList** (list) - 令牌黑名单，支持ipv4，ipv6格式。
        - **ExpireTime** (int) - Unix 时间戳，精确到秒，为令牌过期时间点。默认过期时间为一天（即当前Unix时间戳+86400）；注意：过期时间不能超过 4102416000
        - **WhiteIPList** (list) - 令牌白名单，支持ipv4，ipv6格式。

        **Response**

        - **TokenId** (str) - 令牌唯一ID
        - **UFileTokenSet** (dict) - 见 **UFileTokenSet** 模型定义

        **Response Model**

        **UFileTokenSet**
        - **AllowedBuckets** (list) - 令牌允许操作的bucket
        - **AllowedOps** (list) - 令牌允许执行的操作，[ TOKEN_ALLOW_NONE , TOKEN_ALLOW_READ , TOKEN_ALLOW_WRITE , TOKEN_ALLOW_DELETE , TOKEN_ALLOW_LIST, TOKEN_ALLOW_IOP , TOKEN_ALLOW_DP ]
        - **AllowedPrefixes** (list) - 令牌允许操作的key前缀
        - **BlackIPList** (list) - 令牌黑名单
        - **CreateTime** (int) - 创建时间
        - **ExpireTime** (int) - 令牌的超时时间点
        - **ModifyTime** (int) - 修改时间
        - **PrivateKey** (str) - 令牌私钥
        - **PublicKey** (str) - 令牌公钥
        - **Region** (str) - 所属地区
        - **TokenId** (str) - 令牌ID
        - **TokenName** (str) - 令牌名称
        - **WhiteIPList** (list) - 令牌白名单


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUFileTokenRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUFileToken", d, **kwargs)
        return apis.CreateUFileTokenResponseSchema().loads(resp)

    def delete_bucket(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteBucket - 删除Bucket

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **BucketName** (str) - (Required) 待删除Bucket的名称

        **Response**

        - **BucketId** (str) - Bucket的ID
        - **BucketName** (str) - Bucket的名称

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteBucketRequestSchema().dumps(d)

        resp = self.invoke("DeleteBucket", d, **kwargs)
        return apis.DeleteBucketResponseSchema().loads(resp)

    def delete_ufile_life_cycle(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUFileLifeCycle - 删除生命周期管理

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BucketName** (str) - (Required) 存储空间名称
        - **LifeCycleId** (str) - (Required) 生命周期Id

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUFileLifeCycleRequestSchema().dumps(d)

        resp = self.invoke("DeleteUFileLifeCycle", d, **kwargs)
        return apis.DeleteUFileLifeCycleResponseSchema().loads(resp)

    def delete_ufile_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUFileToken - 删除令牌

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **TokenId** (str) - (Required) 令牌ID

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUFileTokenRequestSchema().dumps(d)

        resp = self.invoke("DeleteUFileToken", d, **kwargs)
        return apis.DeleteUFileTokenResponseSchema().loads(resp)

    def describe_bucket(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeBucket - 获取Bucket的描述信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 如果提供此参数，则获取相应地域下所有空间的空间名称(只返回空间名称信息)
        - **BucketName** (str) - 待获取Bucket的名称，若不提供，则获取所有Bucket
        - **Limit** (int) - 获取所有Bucket列表的限制数目，默认为20
        - **Offset** (int) - 获取所有Bucket列表的偏移数目，默认为0

        **Response**

        - **DataSet** (list) - 见 **UFileBucketSet** 模型定义

        **Response Model**

        **UFileBucketSet**
        - **Biz** (str) - Bucket所属业务, general或vod或udb general: 普通业务； vod: 视频云业务; udb: 云数据库业务
        - **BucketId** (str) - Bucket的ID
        - **BucketName** (str) - Bucket名称
        - **CdnDomainId** (list) - 与Bucket关联的CND加速域名的ID列表
        - **CreateTime** (int) - Bucket的创建时间
        - **Domain** (dict) - 见 **UFileDomainSet** 模型定义
        - **HasUserDomain** (int) - 是否存在自定义域名。0不存在，1存在，2错误
        - **ModifyTime** (int) - Bucket的修改时间
        - **Region** (str) - Bucket所属地域
        - **Tag** (str) - 所属业务组
        - **Type** (str) - Bucket访问类型


        **UFileDomainSet**
        - **Cdn** (list) - UCDN加速域名
        - **CustomCdn** (list) - 用户自定义CDN加速域名
        - **CustomSrc** (list) - 用户自定义源站域名
        - **Src** (list) - 源站域名


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeBucketRequestSchema().dumps(d)

        resp = self.invoke("DescribeBucket", d, **kwargs)
        return apis.DescribeBucketResponseSchema().loads(resp)

    def describe_ufile_life_cycle(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUFileLifeCycle - 获取生命周期信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BucketName** (str) - (Required) 存储空间名称
        - **LifeCycleId** (str) - 生命周期Id；不传递此参数拉取存储空间下面的所有生命周期信息

        **Response**

        - **DateSet** (list) - 见 **LifeCycleItem** 模型定义

        **Response Model**

        **LifeCycleItem**
        - **ArchivalDays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动转换为归档存储类型，0代表不启用；
        - **BucketName** (str) - 存储空间名称
        - **Days** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动删除，0代表不启用；
        - **IADays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动转换为低频存储类型，0代表不启用；
        - **LifeCycleId** (str) - 生命周期Id
        - **LifeCycleName** (str) - 生命周期名称
        - **Prefix** (str) - 生命周期所适用的前缀；*为整个存储空间文件；
        - **Status** (str) - Enabled -- 启用，Disabled -- 不启用


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUFileLifeCycleRequestSchema().dumps(d)

        resp = self.invoke("DescribeUFileLifeCycle", d, **kwargs)
        return apis.DescribeUFileLifeCycleResponseSchema().loads(resp)

    def describe_ufile_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUFileToken - 获取令牌信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **Display** (int) - 0表示显示部分token信息；不传递和其他情况表示显示全部token信息
        - **TokenId** (str) - 令牌ID，只返回指定ID信息，否则拉取所有令牌
        - **TokenName** (str) - 令牌名称，只返回指定令牌名称信息，否则拉取所有令牌

        **Response**

        - **DataSet** (list) - 见 **UFileTokenSet** 模型定义

        **Response Model**

        **UFileTokenSet**
        - **AllowedBuckets** (list) - 令牌允许操作的bucket
        - **AllowedOps** (list) - 令牌允许执行的操作，[ TOKEN_ALLOW_NONE , TOKEN_ALLOW_READ , TOKEN_ALLOW_WRITE , TOKEN_ALLOW_DELETE , TOKEN_ALLOW_LIST, TOKEN_ALLOW_IOP , TOKEN_ALLOW_DP ]
        - **AllowedPrefixes** (list) - 令牌允许操作的key前缀
        - **CreateTime** (int) - 创建时间
        - **ExpireTime** (int) - 令牌的超时时间点
        - **ModifyTime** (int) - 修改时间
        - **PrivateKey** (str) - 令牌私钥
        - **PublicKey** (str) - 令牌公钥
        - **Region** (str) - 所属地区
        - **TokenId** (str) - 令牌ID
        - **TokenName** (str) - 令牌名称


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DescribeUFileTokenRequestSchema().dumps(d)

        resp = self.invoke("DescribeUFileToken", d, **kwargs)
        return apis.DescribeUFileTokenResponseSchema().loads(resp)

    def get_ufile_daily_report(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUFileDailyReport - 查看日消费报表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **EndTime** (int) - (Required) 查询结束时间;unix时间戳,单位s
        - **StartTime** (int) - (Required) 查询开始时间;unix时间戳，单位s
        - **BucketName** (str) - 空间名称。此字段不为空，返回此Bucket日使用量；否则，返回这个项目的日使用量

        **Response**

        - **DataSet** (list) - 见 **UFileReportItem** 模型定义

        **Response Model**

        **UFileReportItem**
        - **Daily** (list) - 见 **UFileDailyReportItem** 模型定义
        - **Total** (list) - 见 **UFileTotalReportItem** 模型定义


        **UFileDailyReportItem**
        - **AcRestore** (float) - 冷存激活量，即归档数据取回量；单位byte
        - **AcStorage** (float) - 冷存（归档）存储量；单位byte
        - **ApiTimes** (float) - API请求次数（万次）
        - **BusyFlow** (float) - 忙时流量；单位byte；海外无此字段
        - **CdnFlow** (float) - cdn回源流量;单位byte
        - **Date** (int) - 配额消费时间，unix时间戳（单位s），精确到日期
        - **Flow** (float) - 下载流量：单位byte；国内无此字段
        - **IaGetSize** (float) - 低频数据取回量；单位byte
        - **IaStorage** (float) - 低频存储量；单位byte
        - **IdleFlow** (float) - 闲时流量；单位byte；海外无此字段
        - **Storage** (float) - 标准存储量；单位byte


        **UFileTotalReportItem**
        - **ApiTimes** (float) - API请求次数（万次）
        - **BusyFlow** (float) - 忙时流量；单位byte；海外无此字段
        - **CdnFlow** (float) - cdn回源流量;单位byte
        - **Flow** (float) - 下载流量：单位byte；国内无此字段
        - **IdleFlow** (float) - 闲时流量；单位byte；海外无此字段


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUFileDailyReportRequestSchema().dumps(d)

        resp = self.invoke("GetUFileDailyReport", d, **kwargs)
        return apis.GetUFileDailyReportResponseSchema().loads(resp)

    def get_ufile_quota(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUFileQuota - 查看配额状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **QuotaType** (str) - (Required) 配额类型，取值为storage-volume, download-traffic或request-count

        **Response**

        - **LeftQuota** (float) - 剩余的配额数值

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUFileQuotaRequestSchema().dumps(d)

        resp = self.invoke("GetUFileQuota", d, **kwargs)
        return apis.GetUFileQuotaResponseSchema().loads(resp)

    def get_ufile_quota_info(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUFileQuotaInfo - 获取配额信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **QuotaType** (list) - (Required) 配额类型，取值为storage-volume, download-traffic或request-count

        **Response**

        - **DataSet** (list) - 见 **UFileQuotaDataSetItem** 模型定义

        **Response Model**

        **UFileQuotaDataSetItem**
        - **DownloadFlow** (dict) - 见 **UFileQuotaLeft** 模型定义
        - **Owe** (int) - 是否欠费：1表示欠费；0表示未欠费
        - **Region** (str) - 可用地域
        - **RequestCnt** (dict) - 见 **UFileQuotaLeft** 模型定义
        - **Storage** (dict) - 见 **UFileQuotaLeft** 模型定义


        **UFileQuotaLeft**
        - **Left** (float) - 配额剩余量


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUFileQuotaInfoRequestSchema().dumps(d)

        resp = self.invoke("GetUFileQuotaInfo", d, **kwargs)
        return apis.GetUFileQuotaInfoResponseSchema().loads(resp)

    def get_ufile_quota_price(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUFileQuotaPrice - 根据US3的购买配额，查询需要支付的价格。

        **Request**

        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **DownloadTraffic** (int) - 下载流量，单位: GB，范围: [0, 60 000]，步长：1GB
        - **RequestCount** (int) - 请求次数，单位：万次，范围：[0, 1 000 000]，步长：1万次
        - **StorageVolume** (int) - 存储容量，单位: GB*天，范围: [0, 30 000 000]，步长：100GB*天

        **Response**

        - **Price** (float) - 待支付价格，单位：分

        """
        # build request
        d = {
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUFileQuotaPriceRequestSchema().dumps(d)

        resp = self.invoke("GetUFileQuotaPrice", d, **kwargs)
        return apis.GetUFileQuotaPriceResponseSchema().loads(resp)

    def get_ufile_report(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUFileReport - 查看配额使用报表

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **EndTime** (int) - (Required) 查询结束时间
        - **StartTime** (int) - (Required) 查询开始时间

        **Response**

        - **DataSet** (list) - 见 **UFileReportSet** 模型定义

        **Response Model**

        **UFileReportSet**
        - **DownloadTraffic** (float) - 配额消费当日使用的下载流量，单位：GB
        - **RequestCount** (float) - 配额消费当日使用的请求次数，单位：万次
        - **StorageVolume** (float) - 配额消费当日使用的存储容量，单位：GB*天
        - **Time** (int) - 配额消费时间，unix时间戳，精确到日期


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUFileReportRequestSchema().dumps(d)

        resp = self.invoke("GetUFileReport", d, **kwargs)
        return apis.GetUFileReportResponseSchema().loads(resp)

    def set_ufile_referer(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SetUFileReferer - 设置对象存储防盗链

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BucketName** (str) - (Required) 存储空间名称
        - **RefererStatus** (str) - (Required) 开启关闭referer防盗链;关闭防盗链会清空防盗链参数设置，开启防盗链必须指定 RefererType、Referers；开启：on， 关闭：off;
        - **RefererAllowNull** (bool) - RefererType为白名单时，RefererAllowNull为false代表不允许空referer访问，为true代表允许空referer访问;此参数默认为 true;
        - **RefererType** (int) - 防盗链Referer类型，支持两种类型，黑名单和白名单; 1黑名单，2白名单；RefererStatus为"on"时此参数必填；
        - **Referers** (list) - 防盗链Referer规则，支持正则表达式（不支持符号';')

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.SetUFileRefererRequestSchema().dumps(d)

        resp = self.invoke("SetUFileReferer", d, **kwargs)
        return apis.SetUFileRefererResponseSchema().loads(resp)

    def update_bucket(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateBucket - 更改Bucket的属性

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **BucketName** (str) - (Required) 待修改Bucket的名称
        - **Type** (str) - (Required) Bucket访问类型;public或private

        **Response**

        - **BucketId** (str) - Bucket的ID
        - **BucketName** (str) - Bucket的名称

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UpdateBucketRequestSchema().dumps(d)

        resp = self.invoke("UpdateBucket", d, **kwargs)
        return apis.UpdateBucketResponseSchema().loads(resp)

    def update_ufile_life_cycle(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUFileLifeCycle - 更新生命周期管理

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **BucketName** (str) - (Required) 存储空间名称
        - **LifeCycleId** (str) - (Required) 生命周期Id
        - **LifeCycleName** (str) - (Required) 生命周期名称
        - **Prefix** (str) - (Required) 生命周期所适用的前缀；*为整个存储空间文件；一条规则只支持一个文件前缀；
        - **Status** (str) - (Required) Enabled -- 启用，Disabled -- 不启用
        - **ArchivalDays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动转换为归档存储类型；范围： [7,36500]，0代表不启用
        - **Days** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期,自动删除；范围： [7,36500]
        - **IADays** (int) - 指定一个过期天数N，文件会在其最近更新时间点的N天后过期，自动转换为低频存储类型；范围： [7,36500]，0代表不启用

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpdateUFileLifeCycleRequestSchema().dumps(d)

        resp = self.invoke("UpdateUFileLifeCycle", d, **kwargs)
        return apis.UpdateUFileLifeCycleResponseSchema().loads(resp)

    def update_ufile_token(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUFileToken - 更新令牌的操作权限，可操作key的前缀，可操作bucket和令牌超时时间点

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **TokenId** (str) - (Required) 令牌ID
        - **AllowedBuckets** (list) - 令牌允许操作的bucket
        - **AllowedOps** (list) - 令牌允许执行的操作，[ TOKEN_ALLOW_NONE , TOKEN_ALLOW_READ , TOKEN_ALLOW_WRITE , TOKEN_ALLOW_DELETE , TOKEN_ALLOW_LIST, TOKEN_ALLOW_IOP , TOKEN_ALLOW_DP ]
        - **AllowedPrefixes** (list) - 令牌允许操作的key前缀
        - **ExpireTime** (int) - 令牌的超时时间点（时间戳）;注意：过期时间不能超过 4102416000
        - **TokenName** (str) - 令牌名称

        **Response**


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpdateUFileTokenRequestSchema().dumps(d)

        resp = self.invoke("UpdateUFileToken", d, **kwargs)
        return apis.UpdateUFileTokenResponseSchema().loads(resp)

    def update_uds_rule(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUdsRule - 针对对象存储的文件，进行自动触发解压。

        **Request**

        - **DstBucket** (str) - (Required) 目标Bucket名字，全局唯一
        - **DstDirectory** (str) - (Required) 解压后的目标目录
        - **DstTokenId** (str) - (Required) 目标bucket的token之一的tokenId
        - **KeepUS3Name** (bool) - (Required) 是否以压缩文件的前缀为最后一层目录
        - **Prefixes** (str) - (Required) 触发解压缩的前缀
        - **RuleId** (str) - (Required) 规则的唯一Id
        - **RuleName** (str) - (Required) 规则名称
        - **SrcBucket** (str) - (Required) 源Bucket名字，全局唯一
        - **SrcTokenId** (str) - (Required) 源bucket的token之一的tokenId
        - **ContactGroupId** (str) - 联系的用户组ID
        - **Events** (list) - 通知的事件数组
        - **NotificationTypes** (list) - 通知的类型数组
        - **Ops** (list) - 操作的ops数组,"Ops.0":"unzip"

        **Response**

        - **Mesage** (str) - 该请求的消息成功或者失败的描述
        - **RuleId** (str) - 返回规则的规则ID

        """
        # build request
        d = {}
        req and d.update(req)
        d = apis.UpdateUdsRuleRequestSchema().dumps(d)

        resp = self.invoke("UpdateUdsRule", d, **kwargs)
        return apis.UpdateUdsRuleResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.vpc.schemas import models

""" VPC API Schema
"""


"""
API: AddSnatRule

对于绑定了多个EIP的NAT网关，您可以将一个子网下的某台云主机映射到某个特定的EIP上，规则生效后，则该云主机通过该特定的EIP访问互联网。
"""


class AddSnatRuleRequestSchema(schema.RequestSchema):
    """AddSnatRule - 对于绑定了多个EIP的NAT网关，您可以将一个子网下的某台云主机映射到某个特定的EIP上，规则生效后，则该云主机通过该特定的EIP访问互联网。"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnatIp": fields.Str(required=True, dump_to="SnatIp"),
        "SourceIp": fields.Str(required=True, dump_to="SourceIp"),
    }


class AddSnatRuleResponseSchema(schema.ResponseSchema):
    """AddSnatRule - 对于绑定了多个EIP的NAT网关，您可以将一个子网下的某台云主机映射到某个特定的EIP上，规则生效后，则该云主机通过该特定的EIP访问互联网。"""

    fields = {}


"""
API: AddVPCNetwork

添加VPC网段
"""


class AddVPCNetworkRequestSchema(schema.RequestSchema):
    """AddVPCNetwork - 添加VPC网段"""

    fields = {
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class AddVPCNetworkResponseSchema(schema.ResponseSchema):
    """AddVPCNetwork - 添加VPC网段"""

    fields = {}


"""
API: AddWhiteListResource

添加NAT网关白名单
"""


class AddWhiteListResourceRequestSchema(schema.RequestSchema):
    """AddWhiteListResource - 添加NAT网关白名单"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceIds": fields.List(fields.Str()),
    }


class AddWhiteListResourceResponseSchema(schema.ResponseSchema):
    """AddWhiteListResource - 添加NAT网关白名单"""

    fields = {}


"""
API: AllocateBatchSecondaryIp

批量申请虚拟网卡辅助IP
"""


class AllocateBatchSecondaryIpRequestSchema(schema.RequestSchema):
    """AllocateBatchSecondaryIp - 批量申请虚拟网卡辅助IP"""

    fields = {
        "Count": fields.Int(required=False, dump_to="Count"),
        "Ip": fields.List(fields.Str()),
        "Mac": fields.Str(required=True, dump_to="Mac"),
        "ObjectId": fields.Str(required=True, dump_to="ObjectId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AllocateBatchSecondaryIpResponseSchema(schema.ResponseSchema):
    """AllocateBatchSecondaryIp - 批量申请虚拟网卡辅助IP"""

    fields = {
        "IpsInfo": fields.List(
            models.IpsInfoSchema(), required=True, load_from="IpsInfo"
        ),
    }


"""
API: AllocateSecondaryIp

分配ip（用于uk8s使用）
"""


class AllocateSecondaryIpRequestSchema(schema.RequestSchema):
    """AllocateSecondaryIp - 分配ip（用于uk8s使用）"""

    fields = {
        "Ip": fields.Str(required=False, dump_to="Ip"),
        "Mac": fields.Str(required=True, dump_to="Mac"),
        "ObjectId": fields.Str(required=True, dump_to="ObjectId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AllocateSecondaryIpResponseSchema(schema.ResponseSchema):
    """AllocateSecondaryIp - 分配ip（用于uk8s使用）"""

    fields = {
        "IpInfo": models.IpInfoSchema(),
    }


"""
API: AllocateVIP

根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。
"""


class AllocateVIPRequestSchema(schema.RequestSchema):
    """AllocateVIP - 根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Count": fields.Int(required=False, dump_to="Count"),
        "Ip": fields.Str(required=False, dump_to="Ip"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AllocateVIPResponseSchema(schema.ResponseSchema):
    """AllocateVIP - 根据提供信息，申请内网VIP(Virtual IP），多用于高可用程序作为漂移IP。"""

    fields = {
        "DataSet": fields.List(
            fields.Str(), required=False, load_from="DataSet"
        ),
        "VIPSet": fields.List(
            models.VIPSetSchema(), required=False, load_from="VIPSet"
        ),
    }


"""
API: AssociateRouteTable

绑定子网的路由表
"""


class AssociateRouteTableRequestSchema(schema.RequestSchema):
    """AssociateRouteTable - 绑定子网的路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class AssociateRouteTableResponseSchema(schema.ResponseSchema):
    """AssociateRouteTable - 绑定子网的路由表"""

    fields = {}


"""
API: AttachNetworkInterface

绑定网卡到云主机
"""


class AttachNetworkInterfaceRequestSchema(schema.RequestSchema):
    """AttachNetworkInterface - 绑定网卡到云主机"""

    fields = {
        "InstanceId": fields.Str(required=True, dump_to="InstanceId"),
        "InterfaceId": fields.Str(required=True, dump_to="InterfaceId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class AttachNetworkInterfaceResponseSchema(schema.ResponseSchema):
    """AttachNetworkInterface - 绑定网卡到云主机"""

    fields = {}


"""
API: CloneRouteTable

将现有的路由表复制为一张新的路由表
"""


class CloneRouteTableRequestSchema(schema.RequestSchema):
    """CloneRouteTable - 将现有的路由表复制为一张新的路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class CloneRouteTableResponseSchema(schema.ResponseSchema):
    """CloneRouteTable - 将现有的路由表复制为一张新的路由表"""

    fields = {
        "RouteTableId": fields.Str(required=False, load_from="RouteTableId"),
    }


"""
API: CreateNATGW

创建NAT网关
"""


class CreateNATGWRequestSchema(schema.RequestSchema):
    """CreateNATGW - 创建NAT网关"""

    fields = {
        "EIPIds": fields.List(fields.Str()),
        "FirewallId": fields.Str(required=True, dump_to="FirewallId"),
        "IfOpen": fields.Int(required=False, dump_to="IfOpen"),
        "NATGWName": fields.Str(required=True, dump_to="NATGWName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SubnetworkIds": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class CreateNATGWResponseSchema(schema.ResponseSchema):
    """CreateNATGW - 创建NAT网关"""

    fields = {
        "NATGWId": fields.Str(required=False, load_from="NATGWId"),
    }


"""
API: CreateNATGWPolicy

添加NAT网关端口转发规则
"""


class CreateNATGWPolicyRequestSchema(schema.RequestSchema):
    """CreateNATGWPolicy - 添加NAT网关端口转发规则"""

    fields = {
        "DstIP": fields.Str(required=True, dump_to="DstIP"),
        "DstPort": fields.Str(required=True, dump_to="DstPort"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "PolicyName": fields.Str(required=False, dump_to="PolicyName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Protocol": fields.Str(required=True, dump_to="Protocol"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SrcEIPId": fields.Str(required=True, dump_to="SrcEIPId"),
        "SrcPort": fields.Str(required=True, dump_to="SrcPort"),
    }


class CreateNATGWPolicyResponseSchema(schema.ResponseSchema):
    """CreateNATGWPolicy - 添加NAT网关端口转发规则"""

    fields = {
        "PolicyId": fields.Str(required=True, load_from="PolicyId"),
    }


"""
API: CreateNetworkAcl

创建网络ACL
"""


class CreateNetworkAclRequestSchema(schema.RequestSchema):
    """CreateNetworkAcl - 创建网络ACL"""

    fields = {
        "AclName": fields.Str(required=True, dump_to="AclName"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VpcId": fields.Str(required=True, dump_to="VpcId"),
    }


class CreateNetworkAclResponseSchema(schema.ResponseSchema):
    """CreateNetworkAcl - 创建网络ACL"""

    fields = {
        "AclId": fields.Str(required=True, load_from="AclId"),
    }


"""
API: CreateNetworkAclAssociation

创建ACL的绑定关系
"""


class CreateNetworkAclAssociationRequestSchema(schema.RequestSchema):
    """CreateNetworkAclAssociation - 创建ACL的绑定关系"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetworkId": fields.Str(required=True, dump_to="SubnetworkId"),
    }


class CreateNetworkAclAssociationResponseSchema(schema.ResponseSchema):
    """CreateNetworkAclAssociation - 创建ACL的绑定关系"""

    fields = {
        "AssociationId": fields.Str(required=True, load_from="AssociationId"),
        "PrevAssociation": models.AssociationInfoSchema(),
    }


"""
API: CreateNetworkAclEntry

创建ACL的规则
"""


class CreateNetworkAclEntryRequestSchema(schema.RequestSchema):
    """CreateNetworkAclEntry - 创建ACL的规则"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "CidrBlock": fields.Str(required=True, dump_to="CidrBlock"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "Direction": fields.Str(required=True, dump_to="Direction"),
        "EntryAction": fields.Str(required=True, dump_to="EntryAction"),
        "IpProtocol": fields.Str(required=True, dump_to="IpProtocol"),
        "PortRange": fields.Str(required=True, dump_to="PortRange"),
        "Priority": fields.Int(required=True, dump_to="Priority"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TargetResourceIds": fields.List(fields.Str()),
        "TargetType": fields.Int(required=False, dump_to="TargetType"),
    }


class CreateNetworkAclEntryResponseSchema(schema.ResponseSchema):
    """CreateNetworkAclEntry - 创建ACL的规则"""

    fields = {
        "EntryId": fields.Str(required=True, load_from="EntryId"),
    }


"""
API: CreateNetworkInterface

创建虚拟网卡
"""


class CreateNetworkInterfaceRequestSchema(schema.RequestSchema):
    """CreateNetworkInterface - 创建虚拟网卡"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "PrivateIp": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "SecurityGroupId": fields.Str(
            required=False, dump_to="SecurityGroupId"
        ),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateNetworkInterfaceResponseSchema(schema.ResponseSchema):
    """CreateNetworkInterface - 创建虚拟网卡"""

    fields = {
        "NetworkInterface": models.NetworkInterfaceInfoSchema(),
    }


"""
API: CreateRouteTable

创建路由表
"""


class CreateRouteTableRequestSchema(schema.RequestSchema):
    """CreateRouteTable - 创建路由表"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateRouteTableResponseSchema(schema.ResponseSchema):
    """CreateRouteTable - 创建路由表"""

    fields = {
        "RouteTableId": fields.Str(required=False, load_from="RouteTableId"),
    }


"""
API: CreateSnatDnatRule

调用接口后会自动创建内外网IP之间的SNAT和DNAT规则，支持TCP、UDP协议全端口
"""


class CreateSnatDnatRuleRequestSchema(schema.RequestSchema):
    """CreateSnatDnatRule - 调用接口后会自动创建内外网IP之间的SNAT和DNAT规则，支持TCP、UDP协议全端口"""

    fields = {
        "EIP": fields.List(fields.Str()),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "PrivateIp": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class CreateSnatDnatRuleResponseSchema(schema.ResponseSchema):
    """CreateSnatDnatRule - 调用接口后会自动创建内外网IP之间的SNAT和DNAT规则，支持TCP、UDP协议全端口"""

    fields = {}


"""
API: CreateSubnet

创建子网
"""


class CreateSubnetRequestSchema(schema.RequestSchema):
    """CreateSubnet - 创建子网"""

    fields = {
        "Netmask": fields.Int(required=False, dump_to="Netmask"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Subnet": fields.Str(required=True, dump_to="Subnet"),
        "SubnetName": fields.Str(required=False, dump_to="SubnetName"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateSubnetResponseSchema(schema.ResponseSchema):
    """CreateSubnet - 创建子网"""

    fields = {
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
    }


"""
API: CreateVPC

创建VPC
"""


class CreateVPCRequestSchema(schema.RequestSchema):
    """CreateVPC - 创建VPC"""

    fields = {
        "Name": fields.Str(required=True, dump_to="Name"),
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "Type": fields.Int(
            required=False, dump_to="Type"
        ),  # Deprecated, will be removed at 1.0
    }


class CreateVPCResponseSchema(schema.ResponseSchema):
    """CreateVPC - 创建VPC"""

    fields = {
        "VPCId": fields.Str(required=False, load_from="VPCId"),
    }


"""
API: CreateVPCIntercom

新建VPC互通关系
"""


class CreateVPCIntercomRequestSchema(schema.RequestSchema):
    """CreateVPCIntercom - 新建VPC互通关系"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "DstVPCId": fields.Str(required=True, dump_to="DstVPCId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateVPCIntercomResponseSchema(schema.ResponseSchema):
    """CreateVPCIntercom - 新建VPC互通关系"""

    fields = {}


"""
API: DeleteNATGW

删除NAT网关
"""


class DeleteNATGWRequestSchema(schema.RequestSchema):
    """DeleteNATGW - 删除NAT网关"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseEip": fields.Bool(required=False, dump_to="ReleaseEip"),
    }


class DeleteNATGWResponseSchema(schema.ResponseSchema):
    """DeleteNATGW - 删除NAT网关"""

    fields = {}


"""
API: DeleteNATGWPolicy

删除NAT网关端口转发规则
"""


class DeleteNATGWPolicyRequestSchema(schema.RequestSchema):
    """DeleteNATGWPolicy - 删除NAT网关端口转发规则"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "PolicyId": fields.Str(required=True, dump_to="PolicyId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteNATGWPolicyResponseSchema(schema.ResponseSchema):
    """DeleteNATGWPolicy - 删除NAT网关端口转发规则"""

    fields = {}


"""
API: DeleteNetworkAcl

删除网络ACL
"""


class DeleteNetworkAclRequestSchema(schema.RequestSchema):
    """DeleteNetworkAcl - 删除网络ACL"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteNetworkAclResponseSchema(schema.ResponseSchema):
    """DeleteNetworkAcl - 删除网络ACL"""

    fields = {}


"""
API: DeleteNetworkAclAssociation

删除网络ACL绑定关系
"""


class DeleteNetworkAclAssociationRequestSchema(schema.RequestSchema):
    """DeleteNetworkAclAssociation - 删除网络ACL绑定关系"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetworkId": fields.Str(required=True, dump_to="SubnetworkId"),
    }


class DeleteNetworkAclAssociationResponseSchema(schema.ResponseSchema):
    """DeleteNetworkAclAssociation - 删除网络ACL绑定关系"""

    fields = {}


"""
API: DeleteNetworkAclEntry

删除ACL的规则
"""


class DeleteNetworkAclEntryRequestSchema(schema.RequestSchema):
    """DeleteNetworkAclEntry - 删除ACL的规则"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "EntryId": fields.Str(required=True, dump_to="EntryId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteNetworkAclEntryResponseSchema(schema.ResponseSchema):
    """DeleteNetworkAclEntry - 删除ACL的规则"""

    fields = {}


"""
API: DeleteRouteTable

删除自定义路由表
"""


class DeleteRouteTableRequestSchema(schema.RequestSchema):
    """DeleteRouteTable - 删除自定义路由表"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class DeleteRouteTableResponseSchema(schema.ResponseSchema):
    """DeleteRouteTable - 删除自定义路由表"""

    fields = {}


"""
API: DeleteSecondaryIp

删除ip（用于uk8s使用）
"""


class DeleteSecondaryIpRequestSchema(schema.RequestSchema):
    """DeleteSecondaryIp - 删除ip（用于uk8s使用）"""

    fields = {
        "Ip": fields.Str(required=True, dump_to="Ip"),
        "Mac": fields.Str(required=True, dump_to="Mac"),
        "ObjectId": fields.Str(required=False, dump_to="ObjectId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteSecondaryIpResponseSchema(schema.ResponseSchema):
    """DeleteSecondaryIp - 删除ip（用于uk8s使用）"""

    fields = {}


"""
API: DeleteSnatDnatRule

删除NAT创建内外网IP映射规则
"""


class DeleteSnatDnatRuleRequestSchema(schema.RequestSchema):
    """DeleteSnatDnatRule - 删除NAT创建内外网IP映射规则"""

    fields = {
        "EIP": fields.List(fields.Str()),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "PrivateIp": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DeleteSnatDnatRuleResponseSchema(schema.ResponseSchema):
    """DeleteSnatDnatRule - 删除NAT创建内外网IP映射规则"""

    fields = {}


"""
API: DeleteSnatRule

删除指定的出口规则（SNAT规则）
"""


class DeleteSnatRuleRequestSchema(schema.RequestSchema):
    """DeleteSnatRule - 删除指定的出口规则（SNAT规则）"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SourceIp": fields.Str(required=True, dump_to="SourceIp"),
    }


class DeleteSnatRuleResponseSchema(schema.ResponseSchema):
    """DeleteSnatRule - 删除指定的出口规则（SNAT规则）"""

    fields = {}


"""
API: DeleteSubnet

删除子网
"""


class DeleteSubnetRequestSchema(schema.RequestSchema):
    """DeleteSubnet - 删除子网"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class DeleteSubnetResponseSchema(schema.ResponseSchema):
    """DeleteSubnet - 删除子网"""

    fields = {}


"""
API: DeleteVPC

删除VPC
"""


class DeleteVPCRequestSchema(schema.RequestSchema):
    """DeleteVPC - 删除VPC"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DeleteVPCResponseSchema(schema.ResponseSchema):
    """DeleteVPC - 删除VPC"""

    fields = {}


"""
API: DeleteVPCIntercom

删除VPC互通关系
"""


class DeleteVPCIntercomRequestSchema(schema.RequestSchema):
    """DeleteVPCIntercom - 删除VPC互通关系"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "DstVPCId": fields.Str(required=True, dump_to="DstVPCId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DeleteVPCIntercomResponseSchema(schema.ResponseSchema):
    """DeleteVPCIntercom - 删除VPC互通关系"""

    fields = {}


"""
API: DeleteWhiteListResource

删除NAT网关白名单列表
"""


class DeleteWhiteListResourceRequestSchema(schema.RequestSchema):
    """DeleteWhiteListResource - 删除NAT网关白名单列表"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceIds": fields.List(fields.Str()),
    }


class DeleteWhiteListResourceResponseSchema(schema.ResponseSchema):
    """DeleteWhiteListResource - 删除NAT网关白名单列表"""

    fields = {}


"""
API: DescribeInstanceNetworkInterface

展示云主机绑定的网卡信息
"""


class DescribeInstanceNetworkInterfaceRequestSchema(schema.RequestSchema):
    """DescribeInstanceNetworkInterface - 展示云主机绑定的网卡信息"""

    fields = {
        "InstanceId": fields.Str(required=True, dump_to="InstanceId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeInstanceNetworkInterfaceResponseSchema(schema.ResponseSchema):
    """DescribeInstanceNetworkInterface - 展示云主机绑定的网卡信息"""

    fields = {
        "NetworkInterfaceSet": fields.List(
            models.InstanceNetworkInterfaceSchema(),
            required=True,
            load_from="NetworkInterfaceSet",
        ),
    }


"""
API: DescribeNATGW

获取NAT网关信息
"""


class DescribeNATGWRequestSchema(schema.RequestSchema):
    """DescribeNATGW - 获取NAT网关信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWIds": fields.List(fields.Str()),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeNATGWResponseSchema(schema.ResponseSchema):
    """DescribeNATGW - 获取NAT网关信息"""

    fields = {
        "DataSet": fields.List(
            models.NatGatewayDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeNATGWPolicy

展示NAT网关端口转发规则
"""


class DescribeNATGWPolicyRequestSchema(schema.RequestSchema):
    """DescribeNATGWPolicy - 展示NAT网关端口转发规则"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeNATGWPolicyResponseSchema(schema.ResponseSchema):
    """DescribeNATGWPolicy - 展示NAT网关端口转发规则"""

    fields = {
        "DataSet": fields.List(
            models.NATGWPolicyDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeNetworkAcl

获取网络ACL
"""


class DescribeNetworkAclRequestSchema(schema.RequestSchema):
    """DescribeNetworkAcl - 获取网络ACL"""

    fields = {
        "Limit": fields.Str(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VpcId": fields.Str(required=False, dump_to="VpcId"),
    }


class DescribeNetworkAclResponseSchema(schema.ResponseSchema):
    """DescribeNetworkAcl - 获取网络ACL"""

    fields = {
        "AclList": fields.List(
            models.AclInfoSchema(), required=True, load_from="AclList"
        ),
    }


"""
API: DescribeNetworkAclAssociation

获取网络ACL的绑定关系列表
"""


class DescribeNetworkAclAssociationRequestSchema(schema.RequestSchema):
    """DescribeNetworkAclAssociation - 获取网络ACL的绑定关系列表"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "Limit": fields.Str(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeNetworkAclAssociationResponseSchema(schema.ResponseSchema):
    """DescribeNetworkAclAssociation - 获取网络ACL的绑定关系列表"""

    fields = {
        "AssociationList": fields.List(
            models.AssociationInfoSchema(),
            required=True,
            load_from="AssociationList",
        ),
    }


"""
API: DescribeNetworkAclAssociationBySubnet

获取子网的ACL绑定信息
"""


class DescribeNetworkAclAssociationBySubnetRequestSchema(schema.RequestSchema):
    """DescribeNetworkAclAssociationBySubnet - 获取子网的ACL绑定信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetworkId": fields.Str(required=True, dump_to="SubnetworkId"),
    }


class DescribeNetworkAclAssociationBySubnetResponseSchema(
    schema.ResponseSchema
):
    """DescribeNetworkAclAssociationBySubnet - 获取子网的ACL绑定信息"""

    fields = {
        "Association": models.AssociationInfoSchema(),
    }


"""
API: DescribeNetworkAclEntry

获取ACL的规则信息
"""


class DescribeNetworkAclEntryRequestSchema(schema.RequestSchema):
    """DescribeNetworkAclEntry - 获取ACL的规则信息"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeNetworkAclEntryResponseSchema(schema.ResponseSchema):
    """DescribeNetworkAclEntry - 获取ACL的规则信息"""

    fields = {
        "EntryList": fields.List(
            models.AclEntryInfoSchema(), required=True, load_from="EntryList"
        ),
    }


"""
API: DescribeNetworkInterface

展示虚拟网卡信息
"""


class DescribeNetworkInterfaceRequestSchema(schema.RequestSchema):
    """DescribeNetworkInterface - 展示虚拟网卡信息"""

    fields = {
        "InterfaceId": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NoRecycled": fields.Bool(required=False, dump_to="NoRecycled"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "OnlyDefault": fields.Bool(required=False, dump_to="OnlyDefault"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeNetworkInterfaceResponseSchema(schema.ResponseSchema):
    """DescribeNetworkInterface - 展示虚拟网卡信息"""

    fields = {
        "NetworkInterfaceSet": fields.List(
            models.NetworkInterfaceSchema(),
            required=True,
            load_from="NetworkInterfaceSet",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeRouteTable

获取路由表详细信息(包括路由策略)
"""


class DescribeRouteTableRequestSchema(schema.RequestSchema):
    """DescribeRouteTable - 获取路由表详细信息(包括路由策略)"""

    fields = {
        "Brief": fields.Bool(required=False, dump_to="Brief"),
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "LongId": fields.Str(required=False, dump_to="LongId"),
        "OffSet": fields.Int(required=False, dump_to="OffSet"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=False, dump_to="RouteTableId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeRouteTableResponseSchema(schema.ResponseSchema):
    """DescribeRouteTable - 获取路由表详细信息(包括路由策略)"""

    fields = {
        "RouteTables": fields.List(
            models.RouteTableInfoSchema(),
            required=False,
            load_from="RouteTables",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeSecondaryIp

查询SecondaryIp（uk8s使用）
"""


class DescribeSecondaryIpRequestSchema(schema.RequestSchema):
    """DescribeSecondaryIp - 查询SecondaryIp（uk8s使用）"""

    fields = {
        "Ip": fields.Str(required=False, dump_to="Ip"),
        "Mac": fields.Str(required=False, dump_to="Mac"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(
            required=True, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class DescribeSecondaryIpResponseSchema(schema.ResponseSchema):
    """DescribeSecondaryIp - 查询SecondaryIp（uk8s使用）"""

    fields = {
        "DataSet": fields.List(
            models.IpInfoSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DescribeSnatDnatRule

获取基于NAT创建的内外网IP映射规则信息
"""


class DescribeSnatDnatRuleRequestSchema(schema.RequestSchema):
    """DescribeSnatDnatRule - 获取基于NAT创建的内外网IP映射规则信息"""

    fields = {
        "EIP": fields.List(fields.Str()),
        "NATGWId": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeSnatDnatRuleResponseSchema(schema.ResponseSchema):
    """DescribeSnatDnatRule - 获取基于NAT创建的内外网IP映射规则信息"""

    fields = {
        "DataSet": fields.List(
            models.SnatDnatRuleInfoSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DescribeSnatRule

获取Nat网关的出口规则（SNAT规则）
"""


class DescribeSnatRuleRequestSchema(schema.RequestSchema):
    """DescribeSnatRule - 获取Nat网关的出口规则（SNAT规则）"""

    fields = {
        "Limit": fields.Str(required=False, dump_to="Limit"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Offset": fields.Str(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnatIp": fields.Str(required=False, dump_to="SnatIp"),
        "SourceIp": fields.Str(required=False, dump_to="SourceIp"),
    }


class DescribeSnatRuleResponseSchema(schema.ResponseSchema):
    """DescribeSnatRule - 获取Nat网关的出口规则（SNAT规则）"""

    fields = {
        "DataSet": fields.List(
            models.NATGWSnatRuleSchema(), required=True, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeSubnet

获取子网信息
"""


class DescribeSubnetRequestSchema(schema.RequestSchema):
    """DescribeSubnet - 获取子网信息"""

    fields = {
        "BusinessId": fields.Str(
            required=False, dump_to="BusinessId"
        ),  # Deprecated, will be removed at 1.0
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteTableId": fields.Str(required=False, dump_to="RouteTableId"),
        "ShowAvailableIPs": fields.Bool(
            required=False, dump_to="ShowAvailableIPs"
        ),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "SubnetIds": fields.List(fields.Str()),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class DescribeSubnetResponseSchema(schema.ResponseSchema):
    """DescribeSubnet - 获取子网信息"""

    fields = {
        "DataSet": fields.List(
            models.SubnetInfoSchema(), required=True, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeSubnetResource

展示子网资源
"""


class DescribeSubnetResourceRequestSchema(schema.RequestSchema):
    """DescribeSubnetResource - 展示子网资源"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceType": fields.Str(required=False, dump_to="ResourceType"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class DescribeSubnetResourceResponseSchema(schema.ResponseSchema):
    """DescribeSubnetResource - 展示子网资源"""

    fields = {
        "DataSet": fields.List(
            models.SubnetResourceSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeVIP

获取内网VIP详细信息
"""


class DescribeVIPRequestSchema(schema.RequestSchema):
    """DescribeVIP - 获取内网VIP详细信息"""

    fields = {
        "BusinessId": fields.Str(required=False, dump_to="BusinessId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VIPId": fields.Str(required=False, dump_to="VIPId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeVIPResponseSchema(schema.ResponseSchema):
    """DescribeVIP - 获取内网VIP详细信息"""

    fields = {
        "DataSet": fields.List(
            fields.Str(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "VIPSet": fields.List(
            models.VIPDetailSetSchema(), required=False, load_from="VIPSet"
        ),
    }


"""
API: DescribeVPC

获取VPC信息
"""


class DescribeVPCRequestSchema(schema.RequestSchema):
    """DescribeVPC - 获取VPC信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCIds": fields.List(fields.Str()),
    }


class DescribeVPCResponseSchema(schema.ResponseSchema):
    """DescribeVPC - 获取VPC信息"""

    fields = {
        "DataSet": fields.List(
            models.VPCInfoSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DescribeVPCIntercom

获取VPC互通信息
"""


class DescribeVPCIntercomRequestSchema(schema.RequestSchema):
    """DescribeVPCIntercom - 获取VPC互通信息"""

    fields = {
        "DstProjectId": fields.Str(required=False, dump_to="DstProjectId"),
        "DstRegion": fields.Str(required=False, dump_to="DstRegion"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class DescribeVPCIntercomResponseSchema(schema.ResponseSchema):
    """DescribeVPCIntercom - 获取VPC互通信息"""

    fields = {
        "DataSet": fields.List(
            models.VPCIntercomInfoSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DescribeWhiteListResource

展示NAT网关白名单资源列表
"""


class DescribeWhiteListResourceRequestSchema(schema.RequestSchema):
    """DescribeWhiteListResource - 展示NAT网关白名单资源列表"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWIds": fields.List(fields.Str()),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeWhiteListResourceResponseSchema(schema.ResponseSchema):
    """DescribeWhiteListResource - 展示NAT网关白名单资源列表"""

    fields = {
        "DataSet": fields.List(
            models.NatGWWhitelistDataSetSchema(),
            required=True,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: EnableWhiteList

修改NAT网关白名单开关
"""


class EnableWhiteListRequestSchema(schema.RequestSchema):
    """EnableWhiteList - 修改NAT网关白名单开关"""

    fields = {
        "IfOpen": fields.Int(required=True, dump_to="IfOpen"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class EnableWhiteListResponseSchema(schema.ResponseSchema):
    """EnableWhiteList - 修改NAT网关白名单开关"""

    fields = {}


"""
API: GetAvailableResourceForPolicy

获取NAT网关可配置端口转发规则的资源信息
"""


class GetAvailableResourceForPolicyRequestSchema(schema.RequestSchema):
    """GetAvailableResourceForPolicy - 获取NAT网关可配置端口转发规则的资源信息"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetAvailableResourceForPolicyResponseSchema(schema.ResponseSchema):
    """GetAvailableResourceForPolicy - 获取NAT网关可配置端口转发规则的资源信息"""

    fields = {
        "DataSet": fields.List(
            models.GetAvailableResourceForPolicyDataSetSchema(),
            required=True,
            load_from="DataSet",
        ),
    }


"""
API: GetAvailableResourceForSnatRule

获取可用于添加snat规则（出口规则）的资源列表
"""


class GetAvailableResourceForSnatRuleRequestSchema(schema.RequestSchema):
    """GetAvailableResourceForSnatRule - 获取可用于添加snat规则（出口规则）的资源列表"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetAvailableResourceForSnatRuleResponseSchema(schema.ResponseSchema):
    """GetAvailableResourceForSnatRule - 获取可用于添加snat规则（出口规则）的资源列表"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "DataSet": fields.List(
            models.GetAvailableResourceForSnatRuleDataSetSchema(),
            required=True,
            load_from="DataSet",
        ),
        "RetCode": fields.Str(required=True, load_from="RetCode"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetAvailableResourceForWhiteList

获取NAT网关可添加白名单的资源
"""


class GetAvailableResourceForWhiteListRequestSchema(schema.RequestSchema):
    """GetAvailableResourceForWhiteList - 获取NAT网关可添加白名单的资源"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetAvailableResourceForWhiteListResponseSchema(schema.ResponseSchema):
    """GetAvailableResourceForWhiteList - 获取NAT网关可添加白名单的资源"""

    fields = {
        "DataSet": fields.List(
            models.GetAvailableResourceForWhiteListDataSetSchema(),
            required=True,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetNetworkAclTargetResource

获取ACL规则应用目标列表
"""


class GetNetworkAclTargetResourceRequestSchema(schema.RequestSchema):
    """GetNetworkAclTargetResource - 获取ACL规则应用目标列表"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetworkId": fields.List(fields.Str()),
    }


class GetNetworkAclTargetResourceResponseSchema(schema.ResponseSchema):
    """GetNetworkAclTargetResource - 获取ACL规则应用目标列表"""

    fields = {
        "TargetResourceList": fields.List(
            models.TargetResourceInfoSchema(),
            required=True,
            load_from="TargetResourceList",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: ListSubnetForNATGW

展示NAT网关可绑定的子网列表
"""


class ListSubnetForNATGWRequestSchema(schema.RequestSchema):
    """ListSubnetForNATGW - 展示NAT网关可绑定的子网列表"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
    }


class ListSubnetForNATGWResponseSchema(schema.ResponseSchema):
    """ListSubnetForNATGW - 展示NAT网关可绑定的子网列表"""

    fields = {
        "DataSet": fields.List(
            models.NatgwSubnetDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
    }


"""
API: ModifyRouteRule

路由策略增、删、改
"""


class ModifyRouteRuleRequestSchema(schema.RequestSchema):
    """ModifyRouteRule - 路由策略增、删、改"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouteRule": fields.List(fields.Str()),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
    }


class ModifyRouteRuleResponseSchema(schema.ResponseSchema):
    """ModifyRouteRule - 路由策略增、删、改"""

    fields = {}


"""
API: MoveSecondaryIPMac

把 Secondary IP 从旧 MAC 迁移到新 MAC
"""


class MoveSecondaryIPMacRequestSchema(schema.RequestSchema):
    """MoveSecondaryIPMac - 把 Secondary IP 从旧 MAC 迁移到新 MAC"""

    fields = {
        "Ip": fields.Str(required=True, dump_to="Ip"),
        "NewMac": fields.Str(required=True, dump_to="NewMac"),
        "OldMac": fields.Str(required=True, dump_to="OldMac"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
    }


class MoveSecondaryIPMacResponseSchema(schema.ResponseSchema):
    """MoveSecondaryIPMac - 把 Secondary IP 从旧 MAC 迁移到新 MAC"""

    fields = {}


"""
API: ReleaseVIP

释放VIP资源
"""


class ReleaseVIPRequestSchema(schema.RequestSchema):
    """ReleaseVIP - 释放VIP资源"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VIPId": fields.Str(required=True, dump_to="VIPId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ReleaseVIPResponseSchema(schema.ResponseSchema):
    """ReleaseVIP - 释放VIP资源"""

    fields = {}


"""
API: SetGwDefaultExport

设置NAT网关的默认出口
"""


class SetGwDefaultExportRequestSchema(schema.RequestSchema):
    """SetGwDefaultExport - 设置NAT网关的默认出口"""

    fields = {
        "ExportEipId": fields.Str(required=False, dump_to="ExportEipId"),
        "ExportIp": fields.Str(required=False, dump_to="ExportIp"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class SetGwDefaultExportResponseSchema(schema.ResponseSchema):
    """SetGwDefaultExport - 设置NAT网关的默认出口"""

    fields = {}


"""
API: UpdateNATGWPolicy

更新NAT网关端口转发规则
"""


class UpdateNATGWPolicyRequestSchema(schema.RequestSchema):
    """UpdateNATGWPolicy - 更新NAT网关端口转发规则"""

    fields = {
        "DstIP": fields.Str(required=True, dump_to="DstIP"),
        "DstPort": fields.Str(required=True, dump_to="DstPort"),
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "PolicyId": fields.Str(required=True, dump_to="PolicyId"),
        "PolicyName": fields.Str(required=False, dump_to="PolicyName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Protocol": fields.Str(required=True, dump_to="Protocol"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SrcEIPId": fields.Str(required=True, dump_to="SrcEIPId"),
        "SrcPort": fields.Str(required=True, dump_to="SrcPort"),
    }


class UpdateNATGWPolicyResponseSchema(schema.ResponseSchema):
    """UpdateNATGWPolicy - 更新NAT网关端口转发规则"""

    fields = {}


"""
API: UpdateNATGWSubnet

更新NAT网关绑定的子网
"""


class UpdateNATGWSubnetRequestSchema(schema.RequestSchema):
    """UpdateNATGWSubnet - 更新NAT网关绑定的子网"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetworkIds": fields.List(fields.Str()),
    }


class UpdateNATGWSubnetResponseSchema(schema.ResponseSchema):
    """UpdateNATGWSubnet - 更新NAT网关绑定的子网"""

    fields = {}


"""
API: UpdateNetworkAcl

更改ACL
"""


class UpdateNetworkAclRequestSchema(schema.RequestSchema):
    """UpdateNetworkAcl - 更改ACL"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "AclName": fields.Str(required=True, dump_to="AclName"),
        "Description": fields.Str(required=True, dump_to="Description"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class UpdateNetworkAclResponseSchema(schema.ResponseSchema):
    """UpdateNetworkAcl - 更改ACL"""

    fields = {}


"""
API: UpdateNetworkAclEntry

更新ACL的规则
"""


class UpdateNetworkAclEntryRequestSchema(schema.RequestSchema):
    """UpdateNetworkAclEntry - 更新ACL的规则"""

    fields = {
        "AclId": fields.Str(required=True, dump_to="AclId"),
        "CidrBlock": fields.Str(required=True, dump_to="CidrBlock"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "Direction": fields.Str(required=True, dump_to="Direction"),
        "EntryAction": fields.Str(required=True, dump_to="EntryAction"),
        "EntryId": fields.Str(required=True, dump_to="EntryId"),
        "IpProtocol": fields.Str(required=True, dump_to="IpProtocol"),
        "PortRange": fields.Str(required=True, dump_to="PortRange"),
        "Priority": fields.Int(required=True, dump_to="Priority"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TargetResourceIds": fields.List(fields.Str()),
        "TargetType": fields.Int(required=False, dump_to="TargetType"),
    }


class UpdateNetworkAclEntryResponseSchema(schema.ResponseSchema):
    """UpdateNetworkAclEntry - 更新ACL的规则"""

    fields = {}


"""
API: UpdateRouteTableAttribute

更新路由表基本信息
"""


class UpdateRouteTableAttributeRequestSchema(schema.RequestSchema):
    """UpdateRouteTableAttribute - 更新路由表基本信息"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "RouteTableId": fields.Str(required=True, dump_to="RouteTableId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateRouteTableAttributeResponseSchema(schema.ResponseSchema):
    """UpdateRouteTableAttribute - 更新路由表基本信息"""

    fields = {}


"""
API: UpdateSnatRule

更新指定的出口规则（SNAT规则）
"""


class UpdateSnatRuleRequestSchema(schema.RequestSchema):
    """UpdateSnatRule - 更新指定的出口规则（SNAT规则）"""

    fields = {
        "NATGWId": fields.Str(required=True, dump_to="NATGWId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SnatIp": fields.Str(required=True, dump_to="SnatIp"),
        "SourceIp": fields.Str(required=True, dump_to="SourceIp"),
    }


class UpdateSnatRuleResponseSchema(schema.ResponseSchema):
    """UpdateSnatRule - 更新指定的出口规则（SNAT规则）"""

    fields = {}


"""
API: UpdateSubnetAttribute

更新子网信息
"""


class UpdateSubnetAttributeRequestSchema(schema.RequestSchema):
    """UpdateSubnetAttribute - 更新子网信息"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class UpdateSubnetAttributeResponseSchema(schema.ResponseSchema):
    """UpdateSubnetAttribute - 更新子网信息"""

    fields = {}


"""
API: UpdateVIPAttribute

更新VIP信息
"""


class UpdateVIPAttributeRequestSchema(schema.RequestSchema):
    """UpdateVIPAttribute - 更新VIP信息"""

    fields = {
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VIPId": fields.Str(required=True, dump_to="VIPId"),
    }


class UpdateVIPAttributeResponseSchema(schema.ResponseSchema):
    """UpdateVIPAttribute - 更新VIP信息"""

    fields = {}


"""
API: UpdateVPCNetwork

更新VPC网段
"""


class UpdateVPCNetworkRequestSchema(schema.RequestSchema):
    """UpdateVPCNetwork - 更新VPC网段"""

    fields = {
        "Network": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class UpdateVPCNetworkResponseSchema(schema.ResponseSchema):
    """UpdateVPCNetwork - 更新VPC网段"""

    fields = {
        "Message": fields.Str(
            required=True, load_from="Message"
        ),  # Deprecated, will be removed at 1.0
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uphone.schemas import models

""" UPhone API Schema
"""


"""
API: CreateUPhone

创建云手机
"""


class CreateUPhoneRequestSchema(schema.RequestSchema):
    """CreateUPhone - 创建云手机"""

    fields = {
        "Bandwidth": fields.Int(required=False, dump_to="Bandwidth"),
        "BindIp": fields.Bool(required=False, dump_to="BindIp"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "IpDestRegion": fields.Str(required=False, dump_to="IpDestRegion"),
        "IpProportion": fields.Int(required=False, dump_to="IpProportion"),
        "MediaBandwidth": fields.Int(required=True, dump_to="MediaBandwidth"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Str(required=False, dump_to="Quantity"),
        "ShareBandwidthId": fields.Str(
            required=False, dump_to="ShareBandwidthId"
        ),
        "ShareBandwidthName": fields.Str(
            required=False, dump_to="ShareBandwidthName"
        ),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UPhoneCount": fields.Int(required=True, dump_to="UPhoneCount"),
        "UPhoneModelName": fields.Str(required=True, dump_to="UPhoneModelName"),
    }


class CreateUPhoneResponseSchema(schema.ResponseSchema):
    """CreateUPhone - 创建云手机"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: CreateUPhoneApp

一个 app 对应多个 app_version。
"""


class CreateUPhoneAppRequestSchema(schema.RequestSchema):
    """CreateUPhoneApp - 一个 app 对应多个 app_version。"""

    fields = {
        "Description": fields.Str(required=False, dump_to="Description"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class CreateUPhoneAppResponseSchema(schema.ResponseSchema):
    """CreateUPhoneApp - 一个 app 对应多个 app_version。"""

    fields = {
        "AppId": fields.Str(required=True, load_from="AppId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: CreateUPhoneAppVersion

创建云手机应用版本。
注：一个 app 对应多个 app_version。
"""


class CreateUPhoneAppVersionRequestSchema(schema.RequestSchema):
    """CreateUPhoneAppVersion - 创建云手机应用版本。
    注：一个 app 对应多个 app_version。
    """

    fields = {
        "AppId": fields.Str(required=True, dump_to="AppId"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "URL": fields.Str(required=True, dump_to="URL"),
    }


class CreateUPhoneAppVersionResponseSchema(schema.ResponseSchema):
    """CreateUPhoneAppVersion - 创建云手机应用版本。
    注：一个 app 对应多个 app_version。
    """

    fields = {
        "AppVersionId": fields.Str(required=True, load_from="AppVersionId"),
    }


"""
API: CreateUPhoneImage

创建云手机镜像。
"""


class CreateUPhoneImageRequestSchema(schema.RequestSchema):
    """CreateUPhoneImage - 创建云手机镜像。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class CreateUPhoneImageResponseSchema(schema.ResponseSchema):
    """CreateUPhoneImage - 创建云手机镜像。"""

    fields = {
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "JobId": fields.Str(required=False, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: CreateUPhoneServer

创建云手机服务器
"""


class CreateUPhoneServerParamNetworkInterfaceSchema(schema.RequestSchema):
    """CreateUPhoneServerParamNetworkInterface -"""

    fields = {}


class CreateUPhoneServerRequestSchema(schema.RequestSchema):
    """CreateUPhoneServer - 创建云手机服务器"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "IpDestRegion": fields.Str(required=False, dump_to="IpDestRegion"),
        "IpProportion": fields.Int(required=False, dump_to="IpProportion"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Str(required=False, dump_to="Quantity"),
        "ServerModelName": fields.Str(required=True, dump_to="ServerModelName"),
        "ShareBandwidth": fields.Int(required=False, dump_to="ShareBandwidth"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UPhoneModelName": fields.Str(required=True, dump_to="UPhoneModelName"),
    }


class CreateUPhoneServerResponseSchema(schema.ResponseSchema):
    """CreateUPhoneServer - 创建云手机服务器"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ServerId": fields.Str(required=True, load_from="ServerId"),
    }


"""
API: DeleteUPhone

删除云手机
"""


class DeleteUPhoneRequestSchema(schema.RequestSchema):
    """DeleteUPhone - 删除云手机"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class DeleteUPhoneResponseSchema(schema.ResponseSchema):
    """DeleteUPhone - 删除云手机"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
    }


"""
API: DeleteUPhoneImage

删除自制云手机镜像。
"""


class DeleteUPhoneImageRequestSchema(schema.RequestSchema):
    """DeleteUPhoneImage - 删除自制云手机镜像。"""

    fields = {
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteUPhoneImageResponseSchema(schema.ResponseSchema):
    """DeleteUPhoneImage - 删除自制云手机镜像。"""

    fields = {
        "ImageId": fields.Str(required=True, load_from="ImageId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DeleteUPhoneServer

删除云手机服务器。
"""


class DeleteUPhoneServerRequestSchema(schema.RequestSchema):
    """DeleteUPhoneServer - 删除云手机服务器。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ReleaseEIP": fields.Bool(required=False, dump_to="ReleaseEIP"),
        "ReleaseUDisk": fields.Bool(required=False, dump_to="ReleaseUDisk"),
        "ServerId": fields.Str(required=True, dump_to="ServerId"),
    }


class DeleteUPhoneServerResponseSchema(schema.ResponseSchema):
    """DeleteUPhoneServer - 删除云手机服务器。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DescribeUPhone

获取云手机列表信息。
"""


class DescribeUPhoneRequestSchema(schema.RequestSchema):
    """DescribeUPhone - 获取云手机列表信息。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "IsAll": fields.Bool(required=False, dump_to="IsAll"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ServerId": fields.Str(required=False, dump_to="ServerId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class DescribeUPhoneResponseSchema(schema.ResponseSchema):
    """DescribeUPhone - 获取云手机列表信息。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
        "UPhones": fields.List(
            models.UPhoneInstanceSchema(), required=True, load_from="UPhones"
        ),
    }


"""
API: DescribeUPhoneApp

获取应用列表。
"""


class DescribeUPhoneAppRequestSchema(schema.RequestSchema):
    """DescribeUPhoneApp - 获取应用列表。"""

    fields = {
        "AppIds": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUPhoneAppResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneApp - 获取应用列表。"""

    fields = {
        "Apps": fields.List(
            models.AppInstanceSchema(), required=False, load_from="Apps"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneAppVersion

获取应用版本列表。
"""


class DescribeUPhoneAppVersionRequestSchema(schema.RequestSchema):
    """DescribeUPhoneAppVersion - 获取应用版本列表。"""

    fields = {
        "AppId": fields.Str(required=False, dump_to="AppId"),
        "AppVersionIds": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=False, dump_to="UPhoneId"),
    }


class DescribeUPhoneAppVersionResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneAppVersion - 获取应用版本列表。"""

    fields = {
        "AppVersions": fields.List(
            models.AppVersionInstanceSchema(),
            required=True,
            load_from="AppVersions",
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneCities

获取云手机提供服务的城市列表
"""


class DescribeUPhoneCitiesRequestSchema(schema.RequestSchema):
    """DescribeUPhoneCities - 获取云手机提供服务的城市列表"""

    fields = {
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUPhoneCitiesResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneCities - 获取云手机提供服务的城市列表"""

    fields = {
        "UPhoneCities": fields.List(
            models.CityInstanceSchema(), required=True, load_from="UPhoneCities"
        ),
    }


"""
API: DescribeUPhoneDetailByApp

根据AppId，查询安装该应用的云手机以及相关的应用版本信息
"""


class DescribeUPhoneDetailByAppRequestSchema(schema.RequestSchema):
    """DescribeUPhoneDetailByApp - 根据AppId，查询安装该应用的云手机以及相关的应用版本信息"""

    fields = {
        "AppId": fields.Str(required=True, dump_to="AppId"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUPhoneDetailByAppResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneDetailByApp - 根据AppId，查询安装该应用的云手机以及相关的应用版本信息"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
        "UPhoneDetails": fields.List(
            models.UPhoneDetailInstanceSchema(),
            required=True,
            load_from="UPhoneDetails",
        ),
    }


"""
API: DescribeUPhoneImage

获取云手机镜像信息列表。  
"""


class DescribeUPhoneImageRequestSchema(schema.RequestSchema):
    """DescribeUPhoneImage - 获取云手机镜像信息列表。"""

    fields = {
        "ImageIds": fields.List(fields.Str()),
        "Limit": fields.Str(required=False, dump_to="Limit"),
        "Offset": fields.Str(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=False, dump_to="Type"),
    }


class DescribeUPhoneImageResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneImage - 获取云手机镜像信息列表。"""

    fields = {
        "Images": fields.List(
            models.UPhoneImageInstanceSchema(),
            required=True,
            load_from="Images",
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneIpRegions

获取云手机所在城市支持绑定独立IP的地域列表
"""


class DescribeUPhoneIpRegionsRequestSchema(schema.RequestSchema):
    """DescribeUPhoneIpRegions - 获取云手机所在城市支持绑定独立IP的地域列表"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DescribeUPhoneIpRegionsResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneIpRegions - 获取云手机所在城市支持绑定独立IP的地域列表"""

    fields = {
        "Regions": fields.List(
            models.IpRegionSchema(), required=True, load_from="Regions"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneJob

查询Job的执行状态。
"""


class DescribeUPhoneJobRequestSchema(schema.RequestSchema):
    """DescribeUPhoneJob - 查询Job的执行状态。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "JobIds": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "State": fields.Str(required=False, dump_to="State"),
        "Types": fields.List(fields.Str()),
    }


class DescribeUPhoneJobResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneJob - 查询Job的执行状态。"""

    fields = {
        "Jobs": fields.List(
            models.JobSchema(), required=False, load_from="Jobs"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneModel

获取云手机规格列表。两种类型：uphone代表单云手机场景、uphone-server代表云手机服务器场景。
"""


class DescribeUPhoneModelRequestSchema(schema.RequestSchema):
    """DescribeUPhoneModel - 获取云手机规格列表。两种类型：uphone代表单云手机场景、uphone-server代表云手机服务器场景。"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneModelNames": fields.List(fields.Str()),
    }


class DescribeUPhoneModelResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneModel - 获取云手机规格列表。两种类型：uphone代表单云手机场景、uphone-server代表云手机服务器场景。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
        "UPhoneModels": fields.List(
            models.UPhoneModelInstanceSchema(),
            required=True,
            load_from="UPhoneModels",
        ),
    }


"""
API: DescribeUPhoneServer

获取云手机服务器列表信息。
"""


class DescribeUPhoneServerRequestSchema(schema.RequestSchema):
    """DescribeUPhoneServer - 获取云手机服务器列表信息。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ServerIds": fields.List(fields.Str()),
    }


class DescribeUPhoneServerResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneServer - 获取云手机服务器列表信息。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "Servers": fields.List(
            models.ServerInstanceSchema(), required=True, load_from="Servers"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: DescribeUPhoneServerModel

获取ServerModel列表。
"""


class DescribeUPhoneServerModelRequestSchema(schema.RequestSchema):
    """DescribeUPhoneServerModel - 获取ServerModel列表。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ServerModelNames": fields.List(fields.Str()),
    }


class DescribeUPhoneServerModelResponseSchema(schema.ResponseSchema):
    """DescribeUPhoneServerModel - 获取ServerModel列表。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ServerModels": fields.List(
            models.ServerModelInstanceSchema(),
            required=False,
            load_from="ServerModels",
        ),
        "Stock": fields.List(
            models.StockInfoSchema(), required=False, load_from="Stock"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetUPhoneAllowance

获取云手机创建余量
"""


class GetUPhoneAllowanceRequestSchema(schema.RequestSchema):
    """GetUPhoneAllowance - 获取云手机创建余量"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUPhoneAllowanceResponseSchema(schema.ResponseSchema):
    """GetUPhoneAllowance - 获取云手机创建余量"""

    fields = {
        "UPhoneAllowance": fields.List(
            models.UPhoneAllowanceSchema(),
            required=True,
            load_from="UPhoneAllowance",
        ),
    }


"""
API: GetUPhonePrice

根据云手机规格名称，获取UPhone实例的价格。
"""


class GetUPhonePriceRequestSchema(schema.RequestSchema):
    """GetUPhonePrice - 根据云手机规格名称，获取UPhone实例的价格。"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "INetBandwidth": fields.Int(required=False, dump_to="INetBandwidth"),
        "IpCount": fields.Int(required=False, dump_to="IpCount"),
        "IpDestRegion": fields.Str(required=False, dump_to="IpDestRegion"),
        "MediaBandwidth": fields.Int(required=False, dump_to="MediaBandwidth"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "UPhoneCount": fields.Int(required=False, dump_to="UPhoneCount"),
        "UPhoneModelName": fields.Int(
            required=False, dump_to="UPhoneModelName"
        ),
    }


class GetUPhonePriceResponseSchema(schema.ResponseSchema):
    """GetUPhonePrice - 根据云手机规格名称，获取UPhone实例的价格。"""

    fields = {
        "PriceSet": fields.List(
            models.UPhonePriceSetSchema(), required=True, load_from="PriceSet"
        ),
    }


"""
API: GetUPhoneRenewPrice

获取云手机续费价格，不包括独立ip价格。
"""


class GetUPhoneRenewPriceRequestSchema(schema.RequestSchema):
    """GetUPhoneRenewPrice - 获取云手机续费价格，不包括独立ip价格。"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class GetUPhoneRenewPriceResponseSchema(schema.ResponseSchema):
    """GetUPhoneRenewPrice - 获取云手机续费价格，不包括独立ip价格。"""

    fields = {
        "PriceSet": fields.List(
            models.UPhonePriceSetSchema(), required=True, load_from="PriceSet"
        ),
    }


"""
API: GetUPhoneScreenCapture

云手机截屏
"""


class GetUPhoneScreenCaptureRequestSchema(schema.RequestSchema):
    """GetUPhoneScreenCapture - 云手机截屏"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneID": fields.Str(required=True, dump_to="UPhoneID"),
    }


class GetUPhoneScreenCaptureResponseSchema(schema.ResponseSchema):
    """GetUPhoneScreenCapture - 云手机截屏"""

    fields = {
        "URL": fields.Str(required=True, load_from="URL"),
    }


"""
API: GetUPhoneServerPrice

根据服务器规格名称，获取UPhoneServer实例的价格。
"""


class GetUPhoneServerPriceRequestSchema(schema.RequestSchema):
    """GetUPhoneServerPrice - 根据服务器规格名称，获取UPhoneServer实例的价格。"""

    fields = {
        "Bandwidth": fields.Int(required=False, dump_to="Bandwidth"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "IpCount": fields.Int(required=False, dump_to="IpCount"),
        "IpDestRegion": fields.Str(required=False, dump_to="IpDestRegion"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "ServerModelName": fields.Str(required=True, dump_to="ServerModelName"),
    }


class GetUPhoneServerPriceResponseSchema(schema.ResponseSchema):
    """GetUPhoneServerPrice - 根据服务器规格名称，获取UPhoneServer实例的价格。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "PriceSet": fields.List(
            models.UPhoneServerPriceSetSchema(),
            required=True,
            load_from="PriceSet",
        ),
    }


"""
API: GetUPhoneServerRenewPrice

获取云手机服务器续费价格

提示信息: 须按照控制台服务器模型配置创建服务器。详情请参考控制台。
"""


class GetUPhoneServerRenewPriceRequestSchema(schema.RequestSchema):
    """GetUPhoneServerRenewPrice - 获取云手机服务器续费价格

    提示信息: 须按照控制台服务器模型配置创建服务器。详情请参考控制台。
    """

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ServerId": fields.Str(required=True, dump_to="ServerId"),
    }


class GetUPhoneServerRenewPriceResponseSchema(schema.ResponseSchema):
    """GetUPhoneServerRenewPrice - 获取云手机服务器续费价格

    提示信息: 须按照控制台服务器模型配置创建服务器。详情请参考控制台。
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "PriceSet": fields.List(
            models.UPhoneServerPriceSetSchema(),
            required=True,
            load_from="PriceSet",
        ),
    }


"""
API: ImportFile

上传文件到云手机目录/sdcard/Download/并自动安装APK文件
"""


class ImportFileRequestSchema(schema.RequestSchema):
    """ImportFile - 上传文件到云手机目录/sdcard/Download/并自动安装APK文件"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "FileName": fields.Str(required=True, dump_to="FileName"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
        "URL": fields.Str(required=True, dump_to="URL"),
    }


class ImportFileResponseSchema(schema.ResponseSchema):
    """ImportFile - 上传文件到云手机目录/sdcard/Download/并自动安装APK文件"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
    }


"""
API: InstallUPhoneAppVersion

在云手机中安装应用版本相关的Apk文件。系统会根据AppVersionId将对应的Apk文件下载后安装到云手机中。一次只支持安装一个Apk。
"""


class InstallUPhoneAppVersionRequestSchema(schema.RequestSchema):
    """InstallUPhoneAppVersion - 在云手机中安装应用版本相关的Apk文件。系统会根据AppVersionId将对应的Apk文件下载后安装到云手机中。一次只支持安装一个Apk。"""

    fields = {
        "AppVersionId": fields.Str(required=True, dump_to="AppVersionId"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class InstallUPhoneAppVersionResponseSchema(schema.ResponseSchema):
    """InstallUPhoneAppVersion - 在云手机中安装应用版本相关的Apk文件。系统会根据AppVersionId将对应的Apk文件下载后安装到云手机中。一次只支持安装一个Apk。"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: ModifyUPhoneName

修改指定云手机实例名称。
"""


class ModifyUPhoneNameRequestSchema(schema.RequestSchema):
    """ModifyUPhoneName - 修改指定云手机实例名称。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class ModifyUPhoneNameResponseSchema(schema.ResponseSchema):
    """ModifyUPhoneName - 修改指定云手机实例名称。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "UPhoneId": fields.Str(required=True, load_from="UPhoneId"),
    }


"""
API: ModifyUPhoneRemark

修改指定云手机实例备注信息。
"""


class ModifyUPhoneRemarkRequestSchema(schema.RequestSchema):
    """ModifyUPhoneRemark - 修改指定云手机实例备注信息。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class ModifyUPhoneRemarkResponseSchema(schema.ResponseSchema):
    """ModifyUPhoneRemark - 修改指定云手机实例备注信息。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "UPhoneId": fields.Str(required=True, load_from="UPhoneId"),
    }


"""
API: ModifyUPhoneServerName

修改指定云手机服务器实例名称。
"""


class ModifyUPhoneServerNameRequestSchema(schema.RequestSchema):
    """ModifyUPhoneServerName - 修改指定云手机服务器实例名称。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "ServerId": fields.Str(required=True, dump_to="ServerId"),
    }


class ModifyUPhoneServerNameResponseSchema(schema.ResponseSchema):
    """ModifyUPhoneServerName - 修改指定云手机服务器实例名称。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ServerId": fields.Str(required=True, load_from="ServerId"),
    }


"""
API: ModifyUPhoneServerRemark

修改指定云手机实例备注信息。
"""


class ModifyUPhoneServerRemarkRequestSchema(schema.RequestSchema):
    """ModifyUPhoneServerRemark - 修改指定云手机实例备注信息。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Remark": fields.Str(required=False, dump_to="Remark"),
        "ServerId": fields.Str(required=True, dump_to="ServerId"),
    }


class ModifyUPhoneServerRemarkResponseSchema(schema.ResponseSchema):
    """ModifyUPhoneServerRemark - 修改指定云手机实例备注信息。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "ServerId": fields.Str(required=True, load_from="ServerId"),
    }


"""
API: PoweroffUPhone

关闭处于运行状态的云手机实例
"""


class PoweroffUPhoneRequestSchema(schema.RequestSchema):
    """PoweroffUPhone - 关闭处于运行状态的云手机实例"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class PoweroffUPhoneResponseSchema(schema.ResponseSchema):
    """PoweroffUPhone - 关闭处于运行状态的云手机实例"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: PoweronUPhone

启动处于关闭状态的云手机实例
"""


class PoweronUPhoneRequestSchema(schema.RequestSchema):
    """PoweronUPhone - 启动处于关闭状态的云手机实例"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class PoweronUPhoneResponseSchema(schema.ResponseSchema):
    """PoweronUPhone - 启动处于关闭状态的云手机实例"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: RebootUPhone

重新启动云手机实例
"""


class RebootUPhoneRequestSchema(schema.RequestSchema):
    """RebootUPhone - 重新启动云手机实例"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class RebootUPhoneResponseSchema(schema.ResponseSchema):
    """RebootUPhone - 重新启动云手机实例"""

    fields = {
        "JobId": fields.Str(required=False, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: RenewUPhone

修改UPhone的device_id、imei、meid 以及其他相关配置，达到一键新机的效果
"""


class RenewUPhoneRequestSchema(schema.RequestSchema):
    """RenewUPhone - 修改UPhone的device_id、imei、meid 以及其他相关配置，达到一键新机的效果"""

    fields = {
        "AndroidID": fields.Str(required=False, dump_to="AndroidID"),
        "BSSID": fields.Str(required=False, dump_to="BSSID"),
        "BaseBand": fields.Str(required=False, dump_to="BaseBand"),
        "Board": fields.Str(required=False, dump_to="Board"),
        "BootLoader": fields.Str(required=False, dump_to="BootLoader"),
        "Brand": fields.Str(required=False, dump_to="Brand"),
        "BuildHost": fields.Str(required=False, dump_to="BuildHost"),
        "BuildID": fields.Str(required=False, dump_to="BuildID"),
        "BuildTags": fields.Str(required=False, dump_to="BuildTags"),
        "BuildVersionInc": fields.Str(
            required=False, dump_to="BuildVersionInc"
        ),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Customize": fields.Bool(required=False, dump_to="Customize"),
        "Device": fields.Str(required=False, dump_to="Device"),
        "DisplayID": fields.Str(required=False, dump_to="DisplayID"),
        "FingerPrint": fields.Str(required=False, dump_to="FingerPrint"),
        "ICCID": fields.Str(required=False, dump_to="ICCID"),
        "IMEI": fields.Str(required=False, dump_to="IMEI"),
        "IMEISV": fields.Str(required=False, dump_to="IMEISV"),
        "IMSI": fields.Str(required=False, dump_to="IMSI"),
        "Manufacture": fields.Str(required=False, dump_to="Manufacture"),
        "Model": fields.Str(required=False, dump_to="Model"),
        "PhoneNumber": fields.Str(required=False, dump_to="PhoneNumber"),
        "ProductName": fields.Str(required=False, dump_to="ProductName"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RadioMac": fields.Str(required=False, dump_to="RadioMac"),
        "SerialNumber": fields.Str(required=False, dump_to="SerialNumber"),
        "UPhoneIds": fields.List(fields.Str()),
        "WiFiName": fields.Str(required=False, dump_to="WiFiName"),
    }


class RenewUPhoneResponseSchema(schema.ResponseSchema):
    """RenewUPhone - 修改UPhone的device_id、imei、meid 以及其他相关配置，达到一键新机的效果"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: ResetUPhone

将云手机恢复为创建时的状态。
"""


class ResetUPhoneRequestSchema(schema.RequestSchema):
    """ResetUPhone - 将云手机恢复为创建时的状态。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class ResetUPhoneResponseSchema(schema.ResponseSchema):
    """ResetUPhone - 将云手机恢复为创建时的状态。"""

    fields = {
        "JobId": fields.Str(required=False, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: RunAsyncCommand

在云手机中执行异步shell命令。
"""


class RunAsyncCommandRequestSchema(schema.RequestSchema):
    """RunAsyncCommand - 在云手机中执行异步shell命令。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Content": fields.Str(required=True, dump_to="Content"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class RunAsyncCommandResponseSchema(schema.ResponseSchema):
    """RunAsyncCommand - 在云手机中执行异步shell命令。"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: RunSyncCommand

在云手机中执行同步shell命令。
"""


class RunSyncCommandRequestSchema(schema.RequestSchema):
    """RunSyncCommand - 在云手机中执行同步shell命令。"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Content": fields.Str(required=True, dump_to="Content"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class RunSyncCommandResponseSchema(schema.ResponseSchema):
    """RunSyncCommand - 在云手机中执行同步shell命令。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "Results": fields.List(
            models.UPhoneCommandResultSchema(),
            required=True,
            load_from="Results",
        ),
    }


"""
API: SetUPhoneCallback

设置云手机异步操作以及状态更新回调，支持云手机重置，安装应用，卸载应用，设备占用状态回调
"""


class SetUPhoneCallbackRequestSchema(schema.RequestSchema):
    """SetUPhoneCallback - 设置云手机异步操作以及状态更新回调，支持云手机重置，安装应用，卸载应用，设备占用状态回调"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
        "URL": fields.Str(required=True, dump_to="URL"),
    }


class SetUPhoneCallbackResponseSchema(schema.ResponseSchema):
    """SetUPhoneCallback - 设置云手机异步操作以及状态更新回调，支持云手机重置，安装应用，卸载应用，设备占用状态回调"""

    fields = {}


"""
API: SetUPhoneConfig

设置云手机画面参数（分辨率、DPI、帧率、码率）
"""


class SetUPhoneConfigRequestSchema(schema.RequestSchema):
    """SetUPhoneConfig - 设置云手机画面参数（分辨率、DPI、帧率、码率）"""

    fields = {
        "Async": fields.Str(required=False, dump_to="Async"),
        "Bitrate": fields.Str(required=False, dump_to="Bitrate"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Dpi": fields.Str(required=False, dump_to="Dpi"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Refresh": fields.Str(required=False, dump_to="Refresh"),
        "Resolution": fields.Str(required=False, dump_to="Resolution"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class SetUPhoneConfigResponseSchema(schema.ResponseSchema):
    """SetUPhoneConfig - 设置云手机画面参数（分辨率、DPI、帧率、码率）"""

    fields = {
        "JobId": fields.Str(required=False, load_from="JobId"),
        "Message": fields.Str(required=False, load_from="Message"),
        "RequestId": fields.Str(required=True, load_from="RequestId"),
        "Results": fields.List(
            models.ResultsSchema(), required=False, load_from="Results"
        ),
    }


"""
API: SetUPhoneGPS

设置云手机GPS信息
"""


class SetUPhoneGPSParamUPhoneGPSsSchema(schema.RequestSchema):
    """SetUPhoneGPSParamUPhoneGPSs -"""

    fields = {
        "Altitude": fields.Float(required=False, dump_to="Altitude"),
        "Latitude": fields.Float(required=False, dump_to="Latitude"),
        "Longitude": fields.Float(required=False, dump_to="Longitude"),
        "UPhoneId": fields.Str(required=False, dump_to="UPhoneId"),
    }


class SetUPhoneGPSRequestSchema(schema.RequestSchema):
    """SetUPhoneGPS - 设置云手机GPS信息"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneGPSs": fields.List(SetUPhoneGPSParamUPhoneGPSsSchema()),
    }


class SetUPhoneGPSResponseSchema(schema.ResponseSchema):
    """SetUPhoneGPS - 设置云手机GPS信息"""

    fields = {
        "JobId": fields.Str(required=False, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: SetUPhoneManagerMode

管理员模式支持所有按键，普通用户模式禁用返回桌面
"""


class SetUPhoneManagerModeRequestSchema(schema.RequestSchema):
    """SetUPhoneManagerMode - 管理员模式支持所有按键，普通用户模式禁用返回桌面"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "Mode": fields.Str(required=True, dump_to="Mode"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class SetUPhoneManagerModeResponseSchema(schema.ResponseSchema):
    """SetUPhoneManagerMode - 管理员模式支持所有按键，普通用户模式禁用返回桌面"""

    fields = {}


"""
API: SetUPhoneRootMode

设置云手机Root模式
"""


class SetUPhoneRootModeRequestSchema(schema.RequestSchema):
    """SetUPhoneRootMode - 设置云手机Root模式"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Root": fields.Bool(required=True, dump_to="Root"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class SetUPhoneRootModeResponseSchema(schema.ResponseSchema):
    """SetUPhoneRootMode - 设置云手机Root模式"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: SetUPhoneSplashScreen

设置云手机启动画面，通过DescribeUPhone接口可以查询该地址
"""


class SetUPhoneSplashScreenRequestSchema(schema.RequestSchema):
    """SetUPhoneSplashScreen - 设置云手机启动画面，通过DescribeUPhone接口可以查询该地址"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
        "URL": fields.Str(required=True, dump_to="URL"),
    }


class SetUPhoneSplashScreenResponseSchema(schema.ResponseSchema):
    """SetUPhoneSplashScreen - 设置云手机启动画面，通过DescribeUPhone接口可以查询该地址"""

    fields = {}


"""
API: SetUPhoneToken

设置云手机RTC连接Token提高安全性
"""


class SetUPhoneTokenRequestSchema(schema.RequestSchema):
    """SetUPhoneToken - 设置云手机RTC连接Token提高安全性"""

    fields = {
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Token": fields.Str(required=False, dump_to="Token"),
        "UPhoneId": fields.Str(required=True, dump_to="UPhoneId"),
    }


class SetUPhoneTokenResponseSchema(schema.ResponseSchema):
    """SetUPhoneToken - 设置云手机RTC连接Token提高安全性"""

    fields = {}


"""
API: UnInstallUPhoneAppVersion

传入应用版本Id，在云手机中根据应用版本的PackageName卸载相关应用。一次只支持卸载一个应用。
"""


class UnInstallUPhoneAppVersionRequestSchema(schema.RequestSchema):
    """UnInstallUPhoneAppVersion - 传入应用版本Id，在云手机中根据应用版本的PackageName卸载相关应用。一次只支持卸载一个应用。"""

    fields = {
        "AppVersionId": fields.Str(required=True, dump_to="AppVersionId"),
        "CityId": fields.Str(required=True, dump_to="CityId"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UPhoneIds": fields.List(fields.Str()),
    }


class UnInstallUPhoneAppVersionResponseSchema(schema.ResponseSchema):
    """UnInstallUPhoneAppVersion - 传入应用版本Id，在云手机中根据应用版本的PackageName卸载相关应用。一次只支持卸载一个应用。"""

    fields = {
        "JobId": fields.Str(required=True, load_from="JobId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: UpdateUPhoneImage

更新云手机镜像信息。
"""


class UpdateUPhoneImageRequestSchema(schema.RequestSchema):
    """UpdateUPhoneImage - 更新云手机镜像信息。"""

    fields = {
        "Description": fields.Str(required=False, dump_to="Description"),
        "ImageId": fields.Str(required=True, dump_to="ImageId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProductType": fields.Str(required=False, dump_to="ProductType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class UpdateUPhoneImageResponseSchema(schema.ResponseSchema):
    """UpdateUPhoneImage - 更新云手机镜像信息。"""

    fields = {
        "ImageId": fields.Str(required=True, load_from="ImageId"),
        "Message": fields.Str(required=True, load_from="Message"),
    }
